==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ShapeSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningShapeStyleEventArgsDescriptionMetadata } from "./AssigningShapeStyleEventArgsDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescriptionMetadata } from "./AssigningShapeMarkerStyleEventArgsDescriptionMetadata";
import { StyleShapeEventArgsDescriptionMetadata } from "./StyleShapeEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var ShapeSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ShapeSeriesBaseDescriptionMetadata, _super);
    function ShapeSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ShapeSeriesBaseDescriptionMetadata.b = function (a) {
        if (ShapeSeriesBaseDescriptionMetadata.a == null) {
            ShapeSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ShapeSeriesBaseDescriptionMetadata.c(ShapeSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(ShapeSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.ab(ShapeSeriesBaseDescriptionMetadata.a);
        AssigningShapeStyleEventArgsDescriptionMetadata.d(a);
        AssigningShapeMarkerStyleEventArgsDescriptionMetadata.d(a);
        StyleShapeEventArgsDescriptionMetadata.d(a);
    };
    ShapeSeriesBaseDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("IsCustomShapeStyleAllowed", "Boolean");
        a.item("IsCustomShapeMarkerStyleAllowed", "Boolean");
        a.item("ActualItemSearchMode", "ExportedType:string:ShapeItemSearchMode");
        a.item("ActualItemSearchMode@names", "Auto;ClosestBoundingBox;ClosestShape;ClosestPointOnClosestShape;None");
        a.item("ItemSearchMode", "ExportedType:string:ShapeItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestBoundingBox;ClosestShape;ClosestPointOnClosestShape;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("ItemSearchPointsThreshold", "Number:int");
        a.item("ShapeMemberPath", "String");
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("ShapeFilterResolution", "Number:double");
        a.item("AssigningShapeStyleRef", "EventRef::assigningShapeStyle");
        a.item("AssigningShapeMarkerStyleRef", "EventRef::assigningShapeMarkerStyle");
        a.item("StyleShapeRef", "EventRef::styleShape");
    };
    ShapeSeriesBaseDescriptionMetadata.d = function (a) {
        ShapeSeriesBaseDescriptionMetadata.b(a);
        a.ac("ShapeSeriesBase", ShapeSeriesBaseDescriptionMetadata.a);
    };
    ShapeSeriesBaseDescriptionMetadata.$t = markType(ShapeSeriesBaseDescriptionMetadata, 'ShapeSeriesBaseDescriptionMetadata');
    ShapeSeriesBaseDescriptionMetadata.a = null;
    return ShapeSeriesBaseDescriptionMetadata;
}(Base));
export { ShapeSeriesBaseDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ShapeSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningShapeStyleEventArgsDescriptionMetadata } from "./AssigningShapeStyleEventArgsDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescriptionMetadata } from "./AssigningShapeMarkerStyleEventArgsDescriptionMetadata";
import { StyleShapeEventArgsDescriptionMetadata } from "./StyleShapeEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var ShapeSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ShapeSeriesBaseDescriptionMetadata, _super);
    function ShapeSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ShapeSeriesBaseDescriptionMetadata.b = function (a) {
        if (ShapeSeriesBaseDescriptionMetadata.a == null) {
            ShapeSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ShapeSeriesBaseDescriptionMetadata.c(ShapeSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(ShapeSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.ac(ShapeSeriesBaseDescriptionMetadata.a);
        AssigningShapeStyleEventArgsDescriptionMetadata.d(a);
        AssigningShapeMarkerStyleEventArgsDescriptionMetadata.d(a);
        StyleShapeEventArgsDescriptionMetadata.d(a);
    };
    ShapeSeriesBaseDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("IsCustomShapeStyleAllowed", "Boolean");
        a.item("IsCustomShapeMarkerStyleAllowed", "Boolean");
        a.item("ActualItemSearchMode", "ExportedType:string:ShapeItemSearchMode");
        a.item("ActualItemSearchMode@names", "Auto;ClosestBoundingBox;ClosestShape;ClosestPointOnClosestShape;None");
        a.item("ItemSearchMode", "ExportedType:string:ShapeItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestBoundingBox;ClosestShape;ClosestPointOnClosestShape;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("ItemSearchPointsThreshold", "Number:int");
        a.item("ShapeMemberPath", "String");
        a.item("HighlightedShapeMemberPath", "String");
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("ShapeFilterResolution", "Number:double");
        a.item("AssigningShapeStyleRef", "EventRef::assigningShapeStyle");
        a.item("AssigningShapeMarkerStyleRef", "EventRef::assigningShapeMarkerStyle");
        a.item("StyleShapeRef", "EventRef::styleShape");
    };
    ShapeSeriesBaseDescriptionMetadata.d = function (a) {
        ShapeSeriesBaseDescriptionMetadata.b(a);
        a.ad("ShapeSeriesBase", ShapeSeriesBaseDescriptionMetadata.a);
    };
    ShapeSeriesBaseDescriptionMetadata.$t = markType(ShapeSeriesBaseDescriptionMetadata, 'ShapeSeriesBaseDescriptionMetadata');
    ShapeSeriesBaseDescriptionMetadata.a = null;
    return ShapeSeriesBaseDescriptionMetadata;
}(Base));
export { ShapeSeriesBaseDescriptionMetadata };
